<?php

namespace Drupal\mcapi_cc\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

class SettingsForm extends ConfigFormBase {

  private $moduleHandler;
  private $transactionRelativeManager;

  /**
   * {@inheritdoc}
   */
  public function getFormID() {
    return 'mcapi_cc_settings_form';
  }

  public function __construct(ConfigFactoryInterface $configFactory, $module_handler, $transaction_relative_manager) {
    $this->setConfigFactory($configFactory);
    $this->moduleHandler = $module_handler;
    $this->transactionRelativeManager = $transaction_relative_manager;
  }

  static public function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('module_handler'),
      $container->get('mcapi.transaction_relative_manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->configFactory->get('mcapi_cc.settings');

    $form['clearingcentral'] = [
      '#title' => t('Clearing Central service'),
      '#type' => 'details',
      '#open' => !$used,
      'curr_id' => [
        '#title' => t('Currency used for intertrading'),
        '#type' => 'mcapi_currency_select',
        '#multiple' => FALSE,
        '#default_value' => $config->get('c')
      ],
      'login' => [
        '#type' => 'textfield',
        '#title' => t('Exchange ID'),
        '#description' => t(
          'Network Identifier in the Community Exchange Network. For example: cen0123. You can check your account at %link.',
          ['%link' => Link::fromTextAndUrl(t('Clearing Central'), \Drupal\Core\Url::fromUri(ClearingCentral::CLEARING_CENTRAL_URL))->toString()]
        ),
        '#size' => 15,
        '#maxlength' => 7,
        '#default_value' => $config->get('login'),
        '#element_validate' => ['::exchangeIdValidate'],
        '#weight' => 2
      ],
      'pass' => [
        '#title' => t('Password'),
        '#type' => 'textfield',
        '#description' => t('Password of the Community Exchange Network account for this exchange. Leave blank to keep the stored password.'),
        '#size' => 15,
        '#default_value' => $config->get('pass'),
        '#weight' => 3
      ]
    ];
    return parent::buildForm($form, $form_state);
  }

  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->configFactory->getEditable('mcapi_cc.settings')
      ->set('login', $form_state->getValue('login'))
      ->set('pass', $form_state->getValue('pass'))
      ->set('currency_id', $form_state->getValue('currency_id'))
      ->save();
  }

  protected function getEditableConfigNames() {
    return ['mcapi_cc.settings'];
  }
  
    
  /**
   * Element validation callback for exchange id on clearing central
   *
   * Value must be 3 letters then 4 numbers.
   */
  static function exchangeIdValidate(&$element, $form_state) {
    if (!preg_match('/[a-zA-Z]{3}[0-9]{4}/', $element['#value'])) {
      $form_state->setError($element, 'Badly formatted login: '.$element['#value']);
    }
  }


}
